@@ -2,7 +2,7 @@
 #
 # Inline::Octave - 
 #
-# $Id: Octave.pm,v 1.27 2004/10/11 13:15:48 aadler Exp $
+# $Id: Octave.pm,v 1.31 2005/09/08 03:07:01 pkienzle Exp $
 
 package Inline::Octave;
 
@@ -10,8 +10,6 @@ $VERSION = '0.21';
 require Inline;
 @ISA = qw(Inline);
 use Carp;
-use IO::File;
-use IPC::Open3;
 use IO::Select;
 use POSIX 'WNOHANG';
 use vars qw( $octave_object );
@@ -129,7 +127,7 @@ sub _validate
   my $switches= "-qfH";
   my $octave_interpreter_bin;
 
-  $octave_interpreter_bin= '/bin/octave-2.1.42-p4atlas.exe' # _EDITLINE_MARKER_
+  $octave_interpreter_bin= 'octave' # _EDITLINE_MARKER_
      unless $octave_object->{INTERP};
 
   $octave_interpreter_bin = $ENV{PERL_INLINE_OCTAVE_BIN}
@@ -230,6 +228,8 @@ sub start_interpreter
    # check if interpreter already alive
    return if $octave_object->{OCTIN} and $octave_object->{OCTOUT};
 
+   use IPC::Open3;
+   use IO::File;
    my $Oin = new IO::File;
    my $Oout= new IO::File;
    my $Oerr= new IO::File;
@@ -245,6 +245,15 @@ sub start_interpreter
 
    my $select= IO::Select->new($Oout, $Oerr);
 
+# New idea - start octave with 
+# use IPC::Run qw(start);
+#  my ($Oin, $Oout, $Oerr);
+#  my $pid;
+#  eval {
+#    $pid= start $octave_object->{INTERP}, \$Oin, \$Oout, \$Oerr
+#  };
+#  croak "Error starting octave interpreter: $@\n" if $@;
+
    $octave_object->{octave_pid} = $pid;
    $octave_object->{OCTIN} = $Oin;
    $octave_object->{OCTOUT} = $Oout;
@@ -325,6 +334,7 @@ sub interpret
    my $Oin=    $octave_object->{OCTIN};
    my $Oerr=   $octave_object->{OCTERR};
    my $select= $octave_object->{SELECT};
+   my $pid   = $octave_object->{octave_pid};
 
    croak "octave interpreter not alive"  unless $Oin and $Oerr;
 
@@ -334,6 +344,8 @@ sub interpret
    local $SIG{PIPE}= \&reap_interpreter;
 
 #  print STDERR "INTERP: $cmd\n";
+#  $Oin = "\n\n$cmd\ndisp('$marker');fflush(stdout);\n";
+#  $pid->pump() while length $Oin;
    print $Oin "\n\n$cmd\ndisp('$marker');fflush(stdout);\n";
 
    my $input= '';
@@ -350,6 +362,12 @@ sub interpret
           }
       }
       last if $input && substr( $input, -$marker_len, -1) eq $marker;
+
+#     $pid->pump();
+
+      process_errors() if $Oerr;
+#     select undef, undef, undef, 0.5 unless $line;
+#     last if substr( $Oout, -$marker_len, -1) eq $marker;
    }   
 
    # we need to leave octave blocked doing something,
@@ -430,11 +448,21 @@ sub run_math_code
 sub get_defined_functions
 {
    my $o = shift;
-   my $data= $o->interpret("whos('-functions')");
+   my $data= $o->interpret("who('-functions')");
    my @funclist;
-   while ( $data =~ /user(-defined|) function +- +- +(\w+)/g )
+   $compiled_fns_marker= 0;
+   while ( $data =~ /(.+)/g )
    {
-      push @funclist, $2;
+      my $line = $1;
+      if(       $line =~ /^\*\*\* .* compiled functions/ ) {
+         $compiled_fns_marker = 1;
+      } elsif ( $line =~ /^\*\*\* / ) {
+         $compiled_fns_marker = 0 ;
+      } elsif ( $line =~ /^[\w\s]+$/ && $compiled_fns_marker ) {
+         while( $line =~ /(\w+)/g ) { 
+             push @funclist, $1;
+         }
+      }
    }
    return @funclist;
 
@@ -768,7 +796,7 @@ sub store_size
 {
    my $self = shift;
    my $varname= $self->name;
-   my $code = "disp([size($varname), is_complex($varname), isstr($varname)] )";
+   my $code = "disp([size($varname), is_complex($varname), ischar($varname)] )";
    my $size=  Inline::Octave::interpret(0, $code );
    croak "Problem constructing Matrix" unless
        $size =~ /^ +(\d+) +(\d+) +([01]) +([01])/;
@@ -1006,7 +1034,7 @@ unless ($Inline::Octave::methods_defined) {
       floor         => 1, gamma         => 1, gammaln       => 1,
       imag          => 1, is_bool       => 1, is_complex    => 1,
       is_global     => 1, is_list       => 1, is_matrix     => 1,
-      is_stream     => 1, is_struct     => 1, isalnum       => 1,
+      is_stream     => 1, isstruct     => 1, isalnum       => 1,
       isalpha       => 1, isascii       => 1, iscell        => 1,
       iscntrl       => 1, isdigit       => 1, isempty       => 1,
       isfinite      => 1, isieee        => 1, isinf         => 1,
@@ -1092,6 +1120,18 @@ TODO LIST:
        - done
 
 $Log: Octave.pm,v $
+Revision 1.31  2005/09/08 03:07:01  pkienzle
+[for Bill Denney] is_struct -> isstruct
+
+Revision 1.30  2005/09/08 02:00:16  pkienzle
+[for Bill Denney] isstr -> ischar
+
+Revision 1.29  2005/03/07 21:45:15  aadler
+fixes for versions
+
+Revision 1.28  2005/03/07 20:20:45  aadler
+version accepts \d.\d\.cvs
+
 Revision 1.27  2004/10/11 13:15:48  aadler
 warning in $input testing
 
@@ -1477,7 +1517,7 @@ number is the output args available (nargout).
       floor       => 1   gamma       => 1   gammaln     => 1  
       imag        => 1   is_bool     => 1   is_complex  => 1  
       is_global   => 1   is_list     => 1   is_matrix   => 1  
-      is_stream   => 1   is_struct   => 1   isalnum     => 1  
+      is_stream   => 1   isstruct   => 1   isalnum     => 1  
       isalpha     => 1   isascii     => 1   iscell      => 1  
       iscntrl     => 1   isdigit     => 1   isempty     => 1  
       isfinite    => 1   isieee      => 1   isinf       => 1  
