@@ -14,7 +14,8 @@
 ## struct.
 
 
-## Author:        Paul Kienzle <pkienzle@kienzle.powernet.co.uk>
+## Author:        Paul Kienzle <pkienzle@users.sf.net>
+## This program is granted to the public domain.
 
 function f = fieldnames(s)
   error("cell arrays unavailable in Octave 2.0; use struct_elements instead");
