@@ -127,7 +127,7 @@ function [Z, FZ, INFO] =fzero(Func,bracket,options,varargin)
 	  usage("[x, fx, info] = fzero(@fcn, [lo,hi]|start, options)"); 
 	endif
 
-	if !isstr(Func) && !isa(Func,"function handle") && !isa(Func,"inline function")
+	if !ischar(Func) && !isa(Func,"function handle") && !isa(Func,"inline function")
 	  error("fzero expects a function as the first argument");
 	endif
 	bracket = bracket(:);
@@ -143,6 +143,9 @@ function [Z, FZ, INFO] =fzero(Func,bracket,options,varargin)
 			options = [];
 		 else 				% nargin > 2
 			if ~isstruct(options)
+				if ~isempty(options)  % empty indicates default chosen
+					warning('Options incorrect. Setting default values.');
+				end
 				warning('Options incorrect. Setting default values.');
 				set_default_options = true;
 			end
