@@ -1,3 +1,15 @@
+## Copyright (C) 2004 Etienne Grossmann.  All rights reserved.
+##
+## This program is free software; you can redistribute it and/or modify it
+## under the terms of the GNU General Public License as published by the
+## Free Software Foundation; either version 2, or (at your option) any
+## later version.
+##
+## This is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+## for more details.
+
 ##       errors = test_struct
 ##
 ## Test whether struct functions behave, and returns the number of errors.
@@ -11,8 +23,8 @@
 ## test counts are displayed at the end of the script (if it is reached).
 ##
 
-## Author:        Etienne Grossmann  <etienne@isr.ist.utl.pt>
-## $Id: test_struct.m,v 1.3 2004/07/23 20:28:30 aadler Exp $
+## Author:        Etienne Grossmann <etienne@cs.uky.edu>
+## $Id: test_struct.m,v 1.5 2005/05/25 03:41:17 pkienzle Exp $
 
 1 ;
 global test_struct_errors  ;
